@@ -5,11 +5,14 @@ extern char **copy_envp(char **envp);
 extern char **update_envp(char **input_envp);
 extern void update_environ(char **envp);
 
-extern char *get_parent_id();
+extern char *get_parent_id(char **envp);
 extern int get_cmd_id();
 
 extern char *getenv_or_fail(const char *name);
 
+char *getenv_from_envp(char **envp, const char *key);
+void setenv_to_envp(char **envp, const char *key, const char *value);
+
 // All environment variables used by clade
 #define CLADE_INTERCEPT_OPEN_ENV "CLADE_INTERCEPT_OPEN"
 #define CLADE_INTERCEPT_EXEC_ENV "CLADE_INTERCEPT"
@@ -19,6 +22,7 @@ extern char *getenv_or_fail(const char *name);
 #define CLADE_INET_HOST_ENV "CLADE_INET_HOST"
 #define CLADE_INET_PORT_ENV "CLADE_INET_PORT"
 #define CLADE_PREPROCESS_ENV "CLADE_PREPROCESS"
+#define CLADE_ENV_VARS_ENV "CLADE_ENV_VARS"
 // Do not forget to add new variables to clade_envs inside env.c
 
 #endif /* ENV_H */
